#ifndef _IPL98_BASLERA113_H
#define _IPL98_BASLERA113_H

#include "../../camera_ipl98_setup.h" /* always include the camera add-on library setup file */
#include <string>
#include <com_visualc/com.h>
#include <camera/camera_framegrabber/camera_fg_std.h> // defines the standard camera base class

#define NOCOMCONNECTION // defined by edr, to be removed later - just in case we can't communicate with camera

namespace ipl{ // use namespace in C++

/** CBaslerA113 camera class. Developed with MS Visual C++ 6.0 but should work
	with other Window platforms such as Borland C++ Builder.
	last updated 17/01/2001.

	@version 0.17
	@author Ren Dencker Eriksen and Peter Hauge */
class CBaslerA113 : public CCameraFGStd
{
private:
	unsigned long m_offset; // for testing only
	/// communication via serial port, allocated by Initialize method.
	CCom* m_pCom;
	/// the port to be used for controlling camera, set by the constructor
	string m_ComPort;

public: // methods
	/** default constructor for the camera class. Sets the comport to "COM2", if
		you want another port use the constructor CBaslerA113(string ComPort). */
	CBaslerA113();
	/** constructor for the camera class
		@param ComPort The com port to be used, use "COM" followed by the port number,
		for instance "COM1" or "COM2" */
	CBaslerA113(string ComPort);
	~CBaslerA113(); // default destructor
	/** Initializes camera and attaches frame grabber instantiated by user.
		Only if more cameras can be connected to a frame grabber the PortNr is used.
		@param fg Framegrabber object instantiated by user.
		@param PortNr Port number on framegrabber if more than one is available, defaults to 0. */
	bool Initialize(CFrameGrabberGeneric& fg,unsigned short PortNr=0);
	/** @name pure virtual functions from CCameraFGStd and CCameraGeneric, see base classes for additional info. */
	//@{
		/** */
		string GetCameraName() const;
		/** */
		bool ShutterAvailable() const;
		/** */
		double GetShutter() const;
		/** */
		double SetShutter(double Value);
		/** */
		double IncShutter();
		/** */
		double DecShutter();
		/** */
		double ShutterDouble();
		/** */
		double ShutterHalf();
		/** */
		bool GainAvailable() const;
		/** */
		double GetGain() const;
		/** */
		double SetGain(double Value);
		/** */
		double IncGain();
		/** */
		double DecGain();
		/** */
		double GetOffset() const;
		/** */
		double SetOffset(double Value);
		/** */
		double IncOffset();
		/** */
		double DecOffset();
		/** */
		double GetOffsetMin() const;
		/** */
		double GetOffsetMax() const;
		/** */
		bool ZoomAvailable() const;
		/** */
		bool PartialScanAvailable() const;
		/** */
		bool Close();
	//@}

	
private:
	// Get the time unit (TU) as 250 ns,500 ns, 1000 ns or 2000 ns
	// Value in nano-seconds
	unsigned long GetTU(double Value);
	// Get the TU corresponding bit combination, 1,2 or 3 followed by 12 zero's
	// TUValue must be 250, 500, 1000 or 2000 (nano-seconds)
	unsigned long GetTUBitComb(unsigned long TUValue);
	// Get multiplier value (range: 0-65535)
	// Value in nano-seconds
	unsigned long GetMultiplier(double Value);
	// Convert unsigned long to hex
	// Value: the value to be converted, HexNumbers hexdigits are converted,
	// str: Result is appended to str
	bool LongToHex(unsigned long Value,unsigned char HexNumbers, string& str);
	char GetHex(unsigned short Value);

};

} // end namespace ipl

#endif //_IPL98_BASLERA113_H