/** Header file of framegrabber class concerning the ITI MVC 150/40 framegrabber	*/
/** Author: Peter Hauge																*/
/** Version 0.1																		*/

#ifndef _IPL98_ITIMVC150_40_H
#define _IPL98_ITIMVC150_40_H

#ifdef _IPL98_TYPES_H /*_IPL98_CPP_H*/
#undef INT16
#undef INT8
#undef INT32
#undef IPL_ERROR
#undef _IPL98_TYPES_H /*_IPL98_CPP_H*/
#endif
#ifdef PIXEL_SIZE
#undef PIXEL_SIZE
#endif

#include <itxcore.h>

#ifdef INT16
#undef INT16
#endif
#ifdef INT8
#undef INT8
#endif
#ifdef INT32
#undef INT32
#endif
#ifdef IPL_ERROR
#undef IPL_ERROR
#endif

#include "../../camera_ipl98_setup.h" /* always include the camera add-on library setup file */
#include <ipl98/cpp/std_image.h>
#include <camera/camera_framegrabber/framegrabber_generic.h>


namespace ipl{ // use namespace in C++

/** Implements the functionallity described by the base class to make
	the ITI MVC 150-40 AM-DIG framegrabber work. This class may not be
    complete and a lot of changes in near future must be expected.
	Last updated 15/8/2000.
	Note: Since the ITI software defines INT32, INT16, INT8 (file PORTDEFS.H),
	and IPL_ERROR (file itxerror.h), you must keep these definitions inside
	the IPL namespace when using this class!

	@version 0.22
	@author Peter Hauge and Ren Dencker Eriksen */
class CITIMVC150_40 : public CFrameGrabberGeneric
{
private:
	MODCNF* m_PcVisionModule;
	short m_AcquisitionModuleFrame;

public:
	/** Default constructor, also calls the base class constructor. */
	CITIMVC150_40();
	/** Default destructor, simply calls the base class destructor. */
	~CITIMVC150_40();
	/** Initializes the framegrabber. A setup file is needed for reading configuration
		for the camera in use. At the MIP lab a Basler A113 is connected to this framegrabber,
		the configuration file "baslerA113.cnf" can be downloaded from the IPL98 homepage
		by choosing "Vision at MIP", choosing the link "Basler A113" and finally following
		the link "Installation notes for Basler A113 with ITI framegrabber". Note: This
		methods sets the baseclass dimension attributes m_Width and m_Height. The base
		class method Open() is also called, i.e. m_DeviceOpen is set to true. Using this
		class means, that you should call this method and not Open() to prepare the 
		framegrabber.
		@param cfgFileName Configuration file for the camera connected to the framegrabber.
		@return False if initialization fails, several checks are done. Errors are
			written to the stream "cerr". */
	bool Initialize(string cfgFileName);
	bool Close();
    /** Acquire image from camera that "Camera" is referring to.
		If the Image has correct dimensions and b/p in advance, the method is
		faster, no reallocation is needed in that case.
		@return false if grabbing failed */
	bool Acquire(CStdImage& Image, CCameraGeneric& Camera);
};

} // end namespace ipl

#endif //_IPL98_ITIMVC150_40_H